==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropIter.h <==
// public final class soot.jimple.spark.solver.PropIter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a813334ed0dcadad soot_jimple_spark_solver_PropIter
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropIter_H_
#define _JC_soot_jimple_spark_solver_PropIter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropIter$sub_refs	_jc_soot_jimple_spark_solver_PropIter$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs	_jc_soot_jimple_spark_solver_PropIter$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$refs	_jc_soot_jimple_spark_solver_PropIter$refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$nonrefs	_jc_soot_jimple_spark_solver_PropIter$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$object	_jc_soot_jimple_spark_solver_PropIter$object;

typedef const struct _jc_soot_jimple_spark_solver_PropIter$vmethods	_jc_soot_jimple_spark_solver_PropIter$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropIter$vtable	_jc_soot_jimple_spark_solver_PropIter$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropIter$vtype	_jc_soot_jimple_spark_solver_PropIter$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropIter$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleLoads$3abae5ab4da4bd4b(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleSimples$cd2a16f7181c90b9(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleStores$046e77d6122e8b90(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern void _jc_soot_jimple_spark_solver_PropIter$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleLoads$3abae5ab4da4bd4b;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleSimples$cd2a16f7181c90b9;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleStores$046e77d6122e8b90;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropIter$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	jboolean	(*handleLoads$3abae5ab4da4bd4b)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);
	jboolean	(*handleSimples$cd2a16f7181c90b9)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	jboolean	(*handleStores$046e77d6122e8b90)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropIter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropIter$vmethods	soot_jimple_spark_solver_PropIter;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropIter$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropIter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter$refs {
    _jc_soot_jimple_spark_solver_PropIter$sub_refs	soot_jimple_spark_solver_PropIter;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs	soot_jimple_spark_solver_PropIter;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropIter$object {
	_jc_soot_jimple_spark_solver_PropIter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropIter$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropIter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropIter$vtype _jc_soot_jimple_spark_solver_PropIter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropIter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropIter$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropIter_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropIter.h <==
// public final class soot.jimple.spark.solver.PropIter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a813334ed0dcadad soot_jimple_spark_solver_PropIter
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropIter_H_
#define _JC_soot_jimple_spark_solver_PropIter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropIter$sub_refs	_jc_soot_jimple_spark_solver_PropIter$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs	_jc_soot_jimple_spark_solver_PropIter$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$refs	_jc_soot_jimple_spark_solver_PropIter$refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$nonrefs	_jc_soot_jimple_spark_solver_PropIter$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter$object	_jc_soot_jimple_spark_solver_PropIter$object;

typedef const struct _jc_soot_jimple_spark_solver_PropIter$vmethods	_jc_soot_jimple_spark_solver_PropIter$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropIter$vtable	_jc_soot_jimple_spark_solver_PropIter$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropIter$vtype	_jc_soot_jimple_spark_solver_PropIter$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropIter$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleLoads$3abae5ab4da4bd4b(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleSimples$cd2a16f7181c90b9(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropIter$method$handleStores$046e77d6122e8b90(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropIter$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleLoads$3abae5ab4da4bd4b;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleSimples$cd2a16f7181c90b9;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$handleStores$046e77d6122e8b90;
extern _jc_method _jc_soot_jimple_spark_solver_PropIter$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropIter$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleLoads$3abae5ab4da4bd4b)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleSimples$cd2a16f7181c90b9)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	jboolean	(*handleStores$046e77d6122e8b90)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropIter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropIter$vmethods	soot_jimple_spark_solver_PropIter;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropIter$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropIter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter$refs {
    _jc_soot_jimple_spark_solver_PropIter$sub_refs	soot_jimple_spark_solver_PropIter;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropIter$sub_nonrefs	soot_jimple_spark_solver_PropIter;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropIter$object {
	_jc_soot_jimple_spark_solver_PropIter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropIter$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropIter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropIter$vtype _jc_soot_jimple_spark_solver_PropIter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropIter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropIter$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropIter_H_ */
